ndn-python-svs
==============

This python library implements the **StateVectorSync** (SVS) protocol_ to synchronise states between multiple clients over NDN for **distributed realtime applications**.

The Named Data Networking (NDN) StateVectorSync Protocol implementation using python-ndn_ and ndn-storage_ nicknamed
``ndn-python-svs`` obtained by the pip library ndn-svs_.

The implementation is on our github-repo_.

There are **two branches**:

* enhanced_: main branch, specification with added enhancements (found in the docs)
* traditional_: original StateVectorSync protocol specification

Please see our documentation_.

.. _protocol: https://named-data.github.io/StateVectorSync
.. _python-ndn: https://github.com/named-data/python-ndn
.. _ndn-storage: https://github.com/justincpresley/ndn-python-storage
.. _ndn-svs: https://pypi.org/project/ndn-svs
.. _documentation: https://ndn-python-svs.readthedocs.io
.. _github-repo: https://github.com/justincpresley/ndn-python-svs
.. _enhanced: https://github.com/justincpresley/ndn-python-svs/tree/enhanced
.. _traditional: https://github.com/justincpresley/ndn-python-svs/tree/traditional
